##  Introduction to Business Capabilities
Business capabilities represent specific abilities or capacities that an organization needs to fulfill its business model. They encompass the organization's high-level activities that contribute to business objectives. Business capabilities define what your organization does to deliver value, independent of how it is achieved by processes or technology.
Each capability represents a distinct function or outcome that is crucial to business success, such as "Customer Management" or "Product Development." Business capabilities don't represent the departments of your organization. Organization fact sheets are used for this purpose.
To learn how to model business capabilities, see [Business Capability Modeling Guidelines](https://help.sap.com/docs/leanix/ea/business-capability-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "This page covers modeling guidelines for business capabilities. Learn about best practices and applicable use cases, and avoid common antipatterns.").
